import stactools.core
from stactools.cli.registry import Registry

from stactools.sentinel1.commands import create_sentinel1_command

stactools.core.use_fsspec()


def register_plugin(registry: Registry):
    # Register subcommands

    registry.register_subcommand(create_sentinel1_command)


__version__ = '0.2.0'



import logging
import os

import click

from stactools.sentinel1.grd.stac import create_item

logger = logging.getLogger(__name__)


@click.group("grd")
def grd_cmd():
    """Commands for working with sentinel1 GRD data"""
    pass


@grd_cmd.command(
    "create-item",
    short_help="Convert a Sentinel1 GRD scene into a STAC item",
)
@click.argument("src")
@click.argument("dst")
def create_item_command(src, dst):
    """Creates a STAC Collection

    Args:
        src (str): path to the scene
        dst (str): path to the STAC Item JSON file that will be created
    """
    item = create_item(src)

    item_path = os.path.join(dst, "{}.json".format(item.id))
    item.set_self_href(item_path)

    item.save_object()



import json
import logging
import os

import click

from stactools.sentinel1.rtc.stac import create_item

logger = logging.getLogger(__name__)


@click.group('rtc')
def rtc_cmd():
    """Commands for working with sentinel1 RTC data"""
    pass


@rtc_cmd.command('create-item',
                 short_help='Convert a Sentinel1 RTC product into a STAC item')
@click.argument('src')
@click.argument('dst')
@click.option('-a',
              '--asset',
              default='local_incident_angle.tif',
              help='Asset geotiff metadata to read')
@click.option('-p',
              '--providers',
              help='Path to JSON file containing array of additional providers'
              )
@click.option('-m',
              '--metadata',
              is_flag=True,
              default=False,
              help='Include links to original GRD metadata as STAC Assets')
def create_item_command(src: str, dst: str, asset: str, providers: str,
                        metadata: bool):
    """Creates a STAC Item for a given Sentinel1 RTC product

    SRC is the path to the granule
    DST is directory that a STAC Item JSON file will be created
    in. for example, ./S1B_20161121_12SYJ_ASC/S1B_20161121_12SYJ_ASC.json
    """
    additional_providers = None
    if providers is not None:
        with open(providers) as f:
            additional_providers = json.load(f)

    item = create_item(src,
                       asset,
                       additional_providers=additional_providers,
                       include_grd_metadata=metadata)
    item_path = os.path.join(dst, f'{item.id}.json')
    item.set_self_href(item_path)
    item.save_object()



import logging
import os
from datetime import datetime
from typing import List, Optional

import pystac
from pystac.collection import Summaries
from pystac.extensions.projection import ProjectionExtension
from pystac.extensions.raster import RasterBand, RasterExtension
from pystac.extensions.sar import SarExtension
from pystac.extensions.sat import OrbitState, SatExtension

from stactools.sentinel1.rtc import constants as c
from stactools.sentinel1.rtc.rtc_metadata import RTCMetadata

logger = logging.getLogger(__name__)


def create_collection() -> pystac.Collection:
    """Creates a STAC Collection for Sentinel-1 RTC
    """
    # Lists of all possible values for items
    summary_dict = {
        'constellation': [c.SENTINEL_CONSTELLATION],
        'platform': c.SENTINEL_PLATFORMS,
        'gsd': [c.SENTINEL_RTC_SAR['gsd']],
        'proj:epsg': c.SENTINEL_RTC_EPSGS
    }

    collection = pystac.Collection(
        'sentinel1-rtc-aws',
        description=c.SENTINEL_RTC_DESCRIPTION,
        extent=c.SENTINEL_RTC_EXTENT,
        title='Sentinel-1 RTC CONUS',
        stac_extensions=[
            SarExtension.get_schema_uri(),
            SatExtension.get_schema_uri(),
            ProjectionExtension.get_schema_uri(),
            RasterExtension.get_schema_uri(),
            # Can use pystac.extensions once implemented
            'https://stac-extensions.github.io/processing/v1.0.0/schema.json',
            'https://stac-extensions.github.io/mgrs/v1.0.0/schema.json',
        ],
        keywords=[
            'backscatter', 'radiometry', 'sentinel', 'copernicus', 'esa', 'sar'
        ],
        providers=[c.SENTINEL_PROVIDER, c.SENTINEL_RTC_PROVIDER],
        summaries=Summaries(summary_dict),
    )

    return collection


def create_item(
    granule_href: str,
    asset_name: str = 'local_incident_angle.tif',
    additional_providers: Optional[List[pystac.Provider]] = None,
    include_grd_metadata: Optional[bool] = False,
) -> pystac.Item:
    """Create a STAC Item from a Sentinel-1 RTC S3 Key

    Arguments:
        granule_href: The HREF to the S3 Key for particular MGRS tile product
            e.g. : s3://sentinel-s1-rtc-indigo/tiles/RTC/1/IW/12/S/YJ/2016/S1B_20161121_12SYJ_ASC
        asset_name: Asset to read geotiff metadata from (Gamma0_VV.tif, local_incident_angle.tif)
        additional_providers: Optional list of additional providers to set into the Item
        include_grd_metadata: Boolean to include links to original GRD metadata as STAC Assets

    Returns:
        pystac.Item: Item populated with STAC core and common extension metadata,
            from the Sentinel 1 RTC Geotiff files.
    """ # noqa
    product_metadata = RTCMetadata(granule_href, asset_name)

    item = pystac.Item(id=product_metadata.product_id,
                       geometry=product_metadata.geometry,
                       bbox=product_metadata.bbox,
                       datetime=product_metadata.datetime,
                       properties={})

    # --Common metadata--
    # https://github.com/radiantearth/stac-spec/blob/master/item-spec/common-metadata.md
    item.common_metadata.providers = [
        c.SENTINEL_PROVIDER, c.SENTINEL_RTC_PROVIDER
    ]

    if additional_providers is not None:
        item.common_metadata.providers.extend(additional_providers)

    item.common_metadata.constellation = c.SENTINEL_CONSTELLATION
    item.common_metadata.platform = product_metadata.platform
    item.common_metadata.instruments = c.SENTINEL_INSTRUMENTS
    item.common_metadata.gsd = c.SENTINEL_RTC_SAR['gsd']

    item.common_metadata.start_datetime = product_metadata.start_datetime
    item.common_metadata.end_datetime = product_metadata.end_datetime

    # STAC Metadata creation date
    item.common_metadata.created = datetime.utcnow()

    # Additional properties no belonging to extensions
    item.properties.update(**product_metadata.metadata_dict)

    # --Extensions--
    # SAR https://github.com/stac-extensions/sar
    sar = SarExtension.ext(item, add_if_missing=True)
    sar.frequency_band = c.SENTINEL_FREQUENCY_BAND
    sar.center_frequency = c.SENTINEL_CENTER_FREQUENCY
    sar.observation_direction = c.SENTINEL_OBSERVATION_DIRECTION
    sar.instrument_mode = c.SENTINEL_RTC_SAR['instrument_mode']
    sar.product_type = c.SENTINEL_RTC_SAR['product_type']
    sar.polarizations = c.SENTINEL_RTC_SAR['polarizations']
    sar.resolution_range = c.SENTINEL_RTC_SAR['resolution_range']
    sar.resolution_azimuth = c.SENTINEL_RTC_SAR['resolution_azimuth']
    sar.pixel_spacing_range = c.SENTINEL_RTC_SAR['pixel_spacing_range']
    sar.pixel_spacing_azimuth = c.SENTINEL_RTC_SAR['pixel_spacing_azimuth']
    sar.looks_equivalent_number = c.SENTINEL_RTC_SAR['looks_equivalent_number']
    sar.looks_range = c.SENTINEL_RTC_SAR['looks_range']
    sar.looks_azimuth = c.SENTINEL_RTC_SAR['looks_azimuth']

    # SAT https://github.com/stac-extensions/sat
    sat = SatExtension.ext(item, add_if_missing=True)
    sat.orbit_state = OrbitState(product_metadata.orbit_state.lower())
    sat.relative_orbit = product_metadata.relative_orbit
    sat.absolute_orbit = product_metadata.absolute_orbit

    # PROJECTION https://github.com/stac-extensions/projection
    projection = ProjectionExtension.ext(item, add_if_missing=True)
    projection.epsg = product_metadata.epsg
    projection.transform = product_metadata.metadata['transform']
    projection.shape = product_metadata.shape

    # --Assets--

    # COGs
    for image in product_metadata.image_paths:
        asset_href = os.path.join(product_metadata.href, image)
        logger.debug(f'Creating asset for image {asset_href}')

        asset = pystac.Asset(href=asset_href,
                             media_type=product_metadata.image_media_type,
                             title=product_metadata.asset_dict[image]['title'],
                             roles=product_metadata.asset_dict[image]['roles'])

        # Raster https://github.com/stac-extensions/raster#raster-band-object
        RasterInfo = product_metadata.asset_dict[image]['raster']
        RasterExtension.ext(asset).bands = [RasterBand.create(**RasterInfo)]

        item.add_asset(product_metadata.asset_dict[image]['key'], asset)

    # Metadata
    if include_grd_metadata:
        for i, grd in enumerate(product_metadata.grd_ids):
            json_href = os.path.join(product_metadata.href, grd,
                                     'productInfo.json')
            asset = pystac.Asset(href=json_href,
                                 media_type=pystac.MediaType.JSON,
                                 title=f'{grd} JSON metadata',
                                 roles=['metadata'])
            item.add_asset(f'productInfo_{i}', asset)

            xml_href = os.path.join(product_metadata.href, grd,
                                    'manifest.safe')
            asset = pystac.Asset(href=xml_href,
                                 media_type=pystac.MediaType.XML,
                                 title=f'{grd} XML metadata',
                                 roles=['metadata'])
            item.add_asset(f'manifest_{i}', asset)

    # --Links--
    # item.links.append(c.SENTINEL_LICENSE)
    item.links.append(c.SENTINEL_RTC_LICENSE)

    return item



import logging
import os

import pystac
from pystac.extensions.eo import EOExtension
from pystac.extensions.projection import ProjectionExtension
from pystac.extensions.sar import SarExtension
from pystac.extensions.sat import SatExtension

from .bands import image_asset_from_href
from .constants import (SENTINEL_CONSTELLATION, SENTINEL_LICENSE,
                        SENTINEL_PROVIDER)
from .metadata_links import MetadataLinks
from .product_metadata import ProductMetadata
from .properties import (fill_proj_properties, fill_sar_properties,
                         fill_sat_properties)

logger = logging.getLogger(__name__)


def create_item(granule_href: str) -> pystac.Item:
    """Create a STC Item from a Sentinel-1 GRD scene.

    Args:
        granule_href (str): The HREF to the granule.
            This is expected to be a path to a SAFE archive.

    Returns:
        pystac.Item: An item representing the Sentinel-1 GRD scene.
    """

    metalinks = MetadataLinks(granule_href)

    product_metadata = ProductMetadata(metalinks.product_metadata_href)

    item = pystac.Item(
        id=product_metadata.scene_id,
        geometry=product_metadata.geometry,
        bbox=product_metadata.bbox,
        datetime=product_metadata.get_datetime,
        properties={},
        stac_extensions=[],
    )

    # ---- Add Extensions ----
    # sar
    sar = SarExtension.ext(item, add_if_missing=True)
    fill_sar_properties(sar, metalinks.product_metadata_href)

    # sat
    sat = SatExtension.ext(item, add_if_missing=True)
    fill_sat_properties(sat, metalinks.product_metadata_href)

    # eo
    EOExtension.ext(item, add_if_missing=True)

    # proj
    proj = ProjectionExtension.ext(item, add_if_missing=True)
    fill_proj_properties(proj, metalinks, product_metadata)

    # --Common metadata--
    item.common_metadata.providers = [SENTINEL_PROVIDER]
    item.common_metadata.platform = product_metadata.platform
    item.common_metadata.constellation = SENTINEL_CONSTELLATION

    # s1 properties
    item.properties.update({**product_metadata.metadata_dict})

    # Add assets to item
    item.add_asset(*metalinks.create_manifest_asset())

    # Annotations for bands
    for asset_obj in metalinks.create_product_asset():
        item.add_asset(asset_obj[0], asset_obj[1])

    # Calibrations for bands
    for asset_obj in metalinks.create_calibration_asset():
        item.add_asset(asset_obj[0], asset_obj[1])

    # Noise for bands
    for asset_obj in metalinks.create_noise_asset():
        item.add_asset(asset_obj[0], asset_obj[1])

    # Thumbnail
    if metalinks.thumbnail_href is not None:
        item.add_asset(
            "thumbnail",
            pystac.Asset(
                href=metalinks.thumbnail_href,
                media_type=pystac.MediaType.PNG,
                roles=["thumbnail"],
            ),
        )

    image_assets = dict([
        image_asset_from_href(
            os.path.join(granule_href, "measurement", image_path),
            item,
        ) for image_path in product_metadata.image_paths
    ])

    for key, asset in image_assets.items():
        assert key not in item.assets
        item.add_asset(key, asset)

    # --Links--
    item.links.append(SENTINEL_LICENSE)

    return item



import click

from stactools.sentinel1.grd.commands import grd_cmd
from stactools.sentinel1.rtc.commands import rtc_cmd


def create_sentinel1_command(cli: click.Group) -> click.Command:
    @cli.group('sentinel1')
    def sentinel1_cmd():
        """Commands for working with sentinel1 data"""
        pass

    sentinel1_cmd.add_command(grd_cmd)
    sentinel1_cmd.add_command(rtc_cmd)

    return sentinel1_cmd



import os
from datetime import datetime
from typing import Any, Dict, List, Optional

from pystac.utils import str_to_datetime
from shapely.geometry import Polygon, mapping  # type: ignore
from stactools.core.io.xml import XmlElement


class ProductMetadataError(Exception):
    pass


class ProductMetadata:
    def __init__(
        self,
        href,
    ) -> None:
        self.href = href
        self._root = XmlElement.from_file(href)

        def _get_geometries():
            # Find the footprint descriptor
            footprint_text = self._root.findall(".//gml:coordinates")
            if footprint_text is None:
                ProductMetadataError(
                    f"Cannot parse footprint from product metadata at {self.href}"
                )
            # Convert to values
            footprint_value = [
                float(x)
                for x in footprint_text[0].text.replace(" ", ",").split(",")
            ]

            footprint_points = [
                p[::-1] for p in list(zip(*[iter(footprint_value)] * 2))
            ]

            footprint_polygon = Polygon(footprint_points)
            geometry = mapping(footprint_polygon)
            bbox = footprint_polygon.bounds

            return (bbox, geometry)

        self.bbox, self.geometry = _get_geometries()

    @property
    def scene_id(self) -> str:
        """Returns the string to be used for a STAC Item id.

        Removes the processing number and .SAFE extension
        from the product_id defined below.

        Parsed based on the naming convention found here:
        https://sentinel.esa.int/web/sentinel/user-guides/sentinel-2-msi/naming-convention
        """
        scene_id = self.product_id.split(".")[0]

        return scene_id

    @property
    def product_id(self) -> str:
        # Parse the name from href as it doesn't exist in xml files
        href = self.href
        result = href.split("/")[-2]
        if result is None:
            raise ValueError(
                "Cannot determine product ID using product metadata "
                f"at {self.href}")
        else:
            return result

    @property
    def get_datetime(self) -> datetime:
        start_time = self._root.findall(".//safe:startTime")[0].text
        end_time = self._root.findall(".//safe:stopTime")[0].text

        central_time = (
            datetime.strptime(start_time, "%Y-%m-%dT%H:%M:%S.%f") +
            (datetime.strptime(end_time, "%Y-%m-%dT%H:%M:%S.%f") -
             datetime.strptime(start_time, "%Y-%m-%dT%H:%M:%S.%f")) / 2)

        if central_time is None:
            raise ValueError(
                "Cannot determine product start time using product metadata "
                f"at {self.href}")
        else:
            return str_to_datetime(str(central_time))

    @property
    def start_datetime(self) -> datetime:
        time = self._root.findall(".//safe:startTime")

        if time is None:
            raise ValueError(
                "Cannot determine product start time using product metadata "
                f"at {self.href}")
        else:
            return str_to_datetime(f"{time[0].text}Z")

    @property
    def end_datetime(self) -> datetime:
        time = self._root.findall(".//safe:stopTime")

        if time is None:
            raise ValueError(
                "Cannot determine product start time using product metadata "
                f"at {self.href}")
        else:
            return str_to_datetime(f"{time[0].text}Z")

    @property
    def platform(self) -> Optional[str]:

        family_name = self._root.findall(".//safe:familyName")[0].text
        platform_name = self._root.findall(".//safe:number")[0].text

        return family_name + platform_name

    @property
    def cycle_number(self) -> Optional[str]:

        return self._root.findall(".//safe:cycleNumber")[0].text

    @property
    def image_paths(self) -> List[str]:
        head_folder = os.path.dirname(self.href)
        measurements = os.path.join(head_folder, "measurement")
        return [x for x in os.listdir(measurements) if x.endswith("tiff")]

    @property
    def metadata_dict(self) -> Dict[str, Any]:
        result = {
            "start_datetime":
            str(self.start_datetime),
            "end_datetime":
            str(self.end_datetime),
            "s1:instrument_configuration_ID":
            self._root.findall(".//s1sarl1:instrumentConfigurationID")[0].text,
            "s1:datatake_id":
            self._root.findall(".//s1sarl1:missionDataTakeID")[0].text,
        }

        return {k: v for k, v in result.items() if v is not None}



import logging
import os
from typing import Optional, Tuple

import pystac
from pystac.extensions.eo import EOExtension

from stactools.sentinel1.grd.constants import SENTINEL_POLARISATIONS

logger = logging.getLogger(__name__)


def image_asset_from_href(
    asset_href: str,
    item: pystac.Item,
    # resolution_to_shape: Dict[int, Tuple[int, int]],
    # proj_bbox: List[float],
    media_type: Optional[str] = None,
) -> Tuple[str, pystac.Asset]:
    logger.debug(f"Creating asset for image {asset_href}")

    _, ext = os.path.splitext(asset_href)
    if media_type is not None:
        asset_media_type = media_type
    else:
        if ext.lower() in [".tiff", ".tif"]:
            asset_media_type = pystac.MediaType.GEOTIFF
        else:
            raise Exception(
                f"Must supply a media type for asset : {asset_href}")

    # Handle band image
    if len(os.path.basename(asset_href).split(".")[0].split("-")) == 2:
        band_id = os.path.basename(asset_href).split(".")[0].split("-")[-1]
    else:
        band_id = os.path.basename(asset_href).split(".")[0].split("-")[3]

    if band_id is not None:
        band = SENTINEL_POLARISATIONS[band_id]
        # Hard code the resolution
        asset_res = "10m"

        # Create asset
        asset = pystac.Asset(
            href=asset_href,
            media_type=asset_media_type,
            title=f"{band.name} - {asset_res}",
            roles=["data"],
        )

        asset_eo = EOExtension.ext(asset)
        asset_eo.bands = [SENTINEL_POLARISATIONS[band_id]]

        return (band_id, asset)

    else:

        raise ValueError(f"Unexpected asset: {asset_href}")



import pystac
from pystac import ProviderRole
from pystac.extensions.eo import Band
from pystac.link import Link

INSPIRE_METADATA_ASSET_KEY = "inspire-metadata"
SAFE_MANIFEST_ASSET_KEY = "safe-manifest"
PRODUCT_METADATA_ASSET_KEY = "product-metadata"

SENTINEL_LICENSE = Link(
    rel="license",
    target="https://sentinel.esa.int/documents/" +
    "247904/690755/Sentinel_Data_Legal_Notice",
)

ACQUISITION_MODES = [
    "Stripmap (SM)",
    "Interferometric Wide Swath (IW)",
    "Extra Wide Swath (EW)",
    "Wave (WV)",
]
SENTINEL_CONSTELLATION = "Sentinel 1"

SENTINEL_PROVIDER = pystac.Provider(
    name="ESA",
    roles=[
        ProviderRole.PRODUCER,
        ProviderRole.PROCESSOR,
        ProviderRole.LICENSOR,
    ],
    url="https://earth.esa.int/web/guest/home",
)

SAFE_MANIFEST_ASSET_KEY = "safe-manifest"

SENTINEL_POLARISATIONS = {
    "vh":
    Band.create(
        name="VH",
        description="vertical transmit and horizontal receive",
    ),
    "hh":
    Band.create(
        name="HH",
        description="horizontal transmit and horizontal receive",
    ),
    "hv":
    Band.create(
        name="HV",
        description="horizontal transmit and vertical receive",
    ),
    "vv":
    Band.create(
        name="VV",
        description="vertical transmit and vertical receive",
    ),
}

SENTINEL_LICENSE = Link(
    rel="license",
    target="https://sentinel.esa.int/documents/" +
    "247904/690755/Sentinel_Data_Legal_Notice",
)



import os
from typing import List, Optional

import pystac
from stactools.core.io.xml import XmlElement

from .constants import SAFE_MANIFEST_ASSET_KEY


class ManifestError(Exception):
    pass


class MetadataLinks:
    def __init__(
        self,
        granule_href: str,
    ):
        self.granule_href = granule_href
        self.href = os.path.join(granule_href, "manifest.safe")

        root = XmlElement.from_file(self.href)
        data_object_section = root.find("dataObjectSection")
        if data_object_section is None:
            raise ManifestError(
                f"Manifest at {self.href} does not have a dataObjectSection")

        self._data_object_section = data_object_section
        self.product_metadata_href = os.path.join(granule_href,
                                                  "manifest.safe")

    def _find_href(self, xpaths: List[str]) -> Optional[str]:
        file_path = None
        for xpath in xpaths:
            file_path = self._data_object_section.find_attr("href", xpath)
            if file_path is not None:
                break

        if file_path is None:
            return None
        else:
            # Remove relative prefix that some paths have
            file_path = file_path.strip("./")
            return os.path.join(self.granule_href, file_path)

    @property
    def thumbnail_href(self) -> Optional[str]:
        preview = os.path.join(self.granule_href, "preview")
        return os.path.join(preview, "quick-look.png")

    @property
    def annotation_hrefs(self) -> List[str]:
        annotation_path = os.path.join(self.granule_href, "annotation")
        return [
            os.path.join(annotation_path, x)
            for x in os.listdir(annotation_path) if x.endswith("xml")
        ]

    @property
    def calibration_hrefs(self) -> List[str]:
        calibration_path = os.path.join(self.granule_href,
                                        "annotation/calibration")
        return [
            os.path.join(calibration_path, x)
            for x in os.listdir(calibration_path)
            if x.endswith("xml") and "calibration" in x
        ]

    @property
    def noise_hrefs(self) -> List[str]:
        calibration_path = os.path.join(self.granule_href,
                                        "annotation/calibration")
        return [
            os.path.join(calibration_path, x)
            for x in os.listdir(calibration_path)
            if x.endswith("xml") and "noise" in x
        ]

    def create_manifest_asset(self):
        asset = pystac.Asset(href=self.href,
                             media_type=pystac.MediaType.XML,
                             roles=["metadata"])
        return (SAFE_MANIFEST_ASSET_KEY, asset)

    def create_product_asset(self):
        assets = []
        for x in self.annotation_hrefs:
            asset = pystac.Asset(
                href=x,
                media_type=pystac.MediaType.XML,
                title="Product Schema",
                roles=["metadata"],
            )
            # Account for different names in SAFE and in Azure
            if len(x.split("/")[-1].split(".")[0].split("-")) > 3:
                assets.append((
                    f"product-{x.split('/')[-1].split('-')[1]}"
                    f"-{x.split('/')[-1].split('-')[3]}",
                    asset,
                ))
            else:
                assets.append(
                    (f"product-{x.split('.')[0].split('/')[-1]}", asset))

        return assets

    def create_calibration_asset(self):
        assets = []
        for x in self.calibration_hrefs:
            asset = pystac.Asset(
                href=x,
                media_type=pystac.MediaType.XML,
                title="Calibration Schema",
                roles=["metadata"],
            )
            # Account for different names in SAFE and in Azure
            if len(x.split("/")[-1].split(".")[0].split("-")) > 3:
                assets.append((
                    f"calibration-{x.split('/')[-1].split('-')[1]}"
                    f"-{x.split('/')[-1].split('-')[3]}",
                    asset,
                ))
            else:
                assets.append((x.split(".")[0].split("/")[-1], asset))

        return assets

    def create_noise_asset(self):
        assets = []
        for x in self.noise_hrefs:
            asset = pystac.Asset(
                href=x,
                media_type=pystac.MediaType.XML,
                title="Noise Schema",
                roles=["metadata"],
            )
            # Account for different names in SAFE and in Azure
            if len(x.split("/")[-1].split(".")[0].split("-")) > 3:
                assets.append((
                    f"calibration-{x.split('/')[-1].split('-')[1]}"
                    f"-{x.split('/')[-1].split('-')[3]}",
                    asset,
                ))
            else:
                assets.append((x.split(".")[0].split("/")[-1], asset))

        return assets



from pystac.extensions.sar import FrequencyBand, Polarization
from pystac.extensions.sat import OrbitState
from stactools.core.io.xml import XmlElement


def fill_sar_properties(sar_ext, href):
    """Fills the properties for SAR.

    Based on the sar Extension.py

    Args:
        input_ext (pystac.extensions.sar.SarExtension): The extension to be populated.
        href (str): The HREF to the scene, this is expected to be an XML file.

    Returns:
        pystac.Asset: An asset with the SAR relevant properties.
    """
    # Read meta file
    root = XmlElement.from_file(href)

    # Fixed properties
    sar_ext.frequency_band = FrequencyBand("C")
    sar_ext.center_frequency = 5.405
    sar_ext.looks_range = 5
    sar_ext.looks_azimuth = 1
    sar_ext.pixel_spacing_range = 10

    # Read properties
    sar_ext.instrument_mode = root.findall(".//s1sarl1:mode")[0].text
    sar_ext.polarizations = [
        Polarization(x.text)
        for x in root.findall(".//s1sarl1:transmitterReceiverPolarisation")
    ]
    sar_ext.product_type = root.findall(".//s1sarl1:productType")[0].text


def fill_sat_properties(sat_ext, href):
    """Fills the properties for SAR.

    Based on the sar Extension.py

    Args:
        input_ext (pystac.extensions.sar.SarExtension): The extension to be populated.
        href (str): The HREF to the scene, this is expected to be an XML file.

    Returns:
        pystac.Asset: An asset with the SAR relevant properties.
    """
    # Read meta file
    root = XmlElement.from_file(href)

    sat_ext.platform_international_designator = root.findall(
        ".//safe:nssdcIdentifier")[0].text

    orbit_state = root.findall(".//s1:pass")[0].text
    sat_ext.orbit_state = OrbitState(orbit_state.lower())

    sat_ext.absolute_orbit = int(root.findall(".//safe:orbitNumber")[0].text)

    sat_ext.relative_orbit = int(
        root.findall(".//safe:relativeOrbitNumber")[0].text)


def fill_proj_properties(proj_ext, meta_links, product_meta):
    """Fills the properties for SAR.

    Based on the sar Extension.py

    Args:
        input_ext (pystac.extensions.sar.SarExtension): The extension to be populated.
        href (str): The HREF to the scene, this is expected to be an XML file.

    Returns:
        pystac.Asset: An asset with the SAR relevant properties.
    """
    # Read meta file
    links = meta_links.create_product_asset()
    root = XmlElement.from_file(links[0][1].href)

    proj_ext.epsg = 4326

    proj_ext.geometry = product_meta.geometry

    proj_ext.bbox = product_meta.bbox

    x_size = int(root.findall(".//numberOfSamples")[0].text)
    y_size = int(root.findall(".//numberOfLines")[0].text)

    proj_ext.shape = [x_size, y_size]
